@@ -14,7 +14,7 @@ class LinearLoss {
 public:
 
 	const sgl::natural n_samples;
-	const sgl::natural n_groups;
+	const sgl::natural n_responses;
 
 private:
 
@@ -22,34 +22,41 @@ private:
 	sgl::vector const& W; //weights - vector of length n_samples
 	sgl::vector const& Y; //response - vector of length n_samples
 
-	sgl::matrix lp; //linear predictors - matrix of size n_samples x n_groups
+	sgl::matrix lp; //linear predictors - matrix of size n_samples x n_responses
 
 	mutable sgl::matrix_field hessian_matrices;
 	mutable bool hessians_computed;
 
 public:
 
-	typedef sgl::WeightedResponseGroupedMatrixData < T , sgl::vector > data_type;
+	//TODO we should test true (constant hessian) and false  (they are constant)
+	typedef sgl::hessian_full<false> hessian_type; //TODO test all types
+	//typedef sgl::hessian_identity hessian_type;
+
+	typedef sgl::DataPackage_4< sgl::MatrixData<T>,
+			sgl::GroupData,
+			sgl::Data<sgl::vector, 'W'>,
+			sgl::Data<sgl::vector, 'Y'> > data_type;
 
 	LinearLoss()
 			: 	n_samples(0),
-				n_groups(0),
+				n_responses(0),
 				G(sgl::null_natural_vector),
 				W(sgl::null_vector),
 				Y(sgl::null_vector),
-				lp(n_samples, n_groups),
+				lp(n_samples, n_responses),
 				hessian_matrices(static_cast < sgl::natural >(0)),
 				hessians_computed(false)
 	{
 	}
 
 	LinearLoss(data_type const& data)
-			: 	n_samples(data.n_samples),
-				n_groups(data.n_groups),
-				G(data.grouping),
-				W(data.weights),
-				Y(data.response),
-				lp(n_samples, n_groups),
+			: 	n_samples(data.get_A().n_samples),
+				n_responses(data.get_B().n_groups),
+				G(data.get_B().grouping),
+				W(data.get_C().data),
+				Y(data.get_D().data),
+				lp(n_samples, n_responses),
 				hessian_matrices(n_samples),
 				hessians_computed(false)
 	{
@@ -59,20 +66,20 @@ public:
 	{
 		this->lp = lp;
 
-		hessians_computed = false;
+		//hessians_computed = false;
 	}
 
 	void set_lp_zero()
 	{
-		lp.zeros(n_samples, n_groups);
+		lp.zeros(n_samples, n_responses);
 
-		hessians_computed = false;
+		//hessians_computed = false;
 	}
 
 	const sgl::matrix gradients() const
 	{
 
-        sgl::matrix grad = arma::zeros < sgl::matrix > (n_groups, n_samples);
+        sgl::matrix grad = arma::zeros < sgl::matrix > (n_responses, n_samples);
 
 		for (sgl::natural i = 0; i < n_samples; ++i)
 		{
@@ -93,7 +100,7 @@ public:
 
 		for (sgl::natural i = 0; i < n_samples; ++i)
 		{
-			hessian_matrices(i).zeros(n_groups, n_groups);
+			hessian_matrices(i).zeros(n_responses, n_responses);
 			hessian_matrices(i)(G(i), G(i)) = 2 * W(i);
 		}
 
@@ -105,6 +112,11 @@ public:
 		return hessian_matrices(i);
 	}
 
+//	const double hessians(sgl::natural i) const
+//	{
+//		return 2 * W(i);
+//	}
+
 	const sgl::numeric sum_values() const
 	{
 
