@@ -33,5 +33,10 @@ res1b <- sgl_predict("sgl_test_sparse", "sglOptim", fit1b, data)
 if(max(abs(fit1a$beta[[25]]-fit1b$beta[[25]])) > 1e-7) stop()
 if(max(abs(res1a$responses$link[[25]]-res1b$responses$link[[25]])) > 1e-7) stop()
 
+# Simple navigate tests
 
-	
+nmod(fit1a)
+models(fit1a)
+coef(fit1a)
+features(fit1a)
+parameters(fit1a)
